@@ -726,12 +726,26 @@ pref("network.IDN.whitelist.vn", true);
 // IDN ccTLDs
 // ae, UAE, .<Emarat>
 pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -819,7 +833,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 849 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 863 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1240,18 +1254,18 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1667 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1681 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1669 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1683 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
 pref("ui.click_hold_context_menus", false);
 
-//@line 1675 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1689 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // whether to always use ATSUI for text even if CoreText is available
 pref("gfx.force_atsui_text", false);
-//@line 1678 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1692 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // default fonts (in UTF8 and using canonical names)
 // to determine canonical font names, use a debug build and 
@@ -1663,21 +1677,21 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2091 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2105 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2294 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2308 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2390 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2404 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2665 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2679 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2733 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2747 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2773 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2793 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2787 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2801 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1714,9 +1728,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2829 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2843 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2834 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2848 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
